@@ -83,8 +83,22 @@ struct MethodMeta {
 
 typedef struct ParamMeta {
   SV *name;
-  FieldMeta *field;
-  FIELDOFFSET fieldix;
+  ClassMeta *class;
+  enum {
+    PARAM_FIELD,
+    PARAM_ADJUST,
+  } type;
+  union {
+    struct {
+      FieldMeta *fieldmeta;
+      FIELDOFFSET fieldix;
+    } field;
+    struct {
+      /* TODO: store the block itself sometime?? */
+      PADOFFSET padix;
+      OP *defexpr;
+    } adjust;
+  };
 } ParamMeta;
 
 #define MOP_CLASS_RUN_HOOKS(classmeta, func, ...)                                         \
@@ -112,6 +126,12 @@ void ObjectPad__start_method_parse(pTHX_ ClassMeta *meta, bool is_common);
 #define finish_method_parse(meta, is_common, body)  ObjectPad__finish_method_parse(aTHX_ meta, is_common, body)
 OP *ObjectPad__finish_method_parse(pTHX_ ClassMeta *meta, bool is_common, OP *body);
 
+#define newop_croak_from_constructor(message)  ObjectPad__newop_croak_from_constructor(aTHX_ message)
+OP *ObjectPad__newop_croak_from_constructor(pTHX_ SV *message);
+
+#define check_colliding_param(classmeta, paramname)  ObjectPad__check_colliding_param(aTHX_ classmeta, paramname)
+void ObjectPad__check_colliding_param(pTHX_ ClassMeta *classmeta, SV *paramname);
+
 void ObjectPad__boot_classes(pTHX);
 
 /* Empty role embedding that is applied to all invokable role methods */
